| bolus_inad | R Documentation |
Morphine bolus self administration counts for two treatment groups recorded at 12 four hour time points. The data are stored in matrix form to facilitate use with antedependence models.
bolus_inad
A list with four components:
integer matrix of dimension N by n_time containing all subjects and time points
integer matrix with rows corresponding to the 2 mg treatment group
integer matrix with rows corresponding to the 1 mg treatment group
integer vector of length N giving the block or treatment group indicator, 1 for 2 mg and 2 for 1 mg
Dataset bolus from the cold package, converted to
matrix form and grouped by treatment.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.