dot-count_cells_cat: Count cells for contingency table

.count_cells_catR Documentation

Count cells for contingency table

Description

Counts occurrences of each combination of categories at specified time indices.

Usage

.count_cells_cat(y, time_indices, n_categories, subject_mask = NULL)

Arguments

y

Data matrix (n_subjects x n_time)

time_indices

Integer vector of time indices to count

n_categories

Number of categories

subject_mask

Logical vector indicating which subjects to include (NULL = all)

Value

Array of counts with dimensions c x c x ... (length = length(time_indices))


antedep documentation built on April 25, 2026, 1:06 a.m.