dot-inad_effective_innovation_param: Effective innovation distribution parameter under block...

.inad_effective_innovation_paramR Documentation

Effective innovation distribution parameter under block effects

Description

For Poisson and negative binomial innovations, block effects are additive on the mean. For Bell innovations, block effects are additive on the innovation mean theta * exp(theta), then mapped back to the Bell parameter.

Usage

.inad_effective_innovation_param(theta, tau, innovation)

antedep documentation built on April 25, 2026, 1:06 a.m.