Morphine bolus self administration counts for two treatment groups recorded at 12 four hour time points. The data are stored in matrix form to facilitate use with antedependence models.
Format
A list with four components:
- y
integer matrix of dimension N by n_time containing all subjects and time points
- y_2mg
integer matrix with rows corresponding to the 2 mg treatment group
- y_1mg
integer matrix with rows corresponding to the 1 mg treatment group
- blocks
integer vector of length N giving the block or treatment group indicator, 1 for 2 mg and 2 for 1 mg