| .count_cells_cat | R Documentation |
Counts occurrences of each combination of categories at specified time indices.
.count_cells_cat(y, time_indices, n_categories, subject_mask = NULL)
y |
Data matrix (n_subjects x n_time) |
time_indices |
Integer vector of time indices to count |
n_categories |
Number of categories |
subject_mask |
Logical vector indicating which subjects to include (NULL = all) |
Array of counts with dimensions c x c x ... (length = length(time_indices))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.