| .inad_effective_innovation_param | R Documentation |
For Poisson and negative binomial innovations, block effects are additive on
the mean. For Bell innovations, block effects are additive on the innovation
mean theta * exp(theta), then mapped back to the Bell parameter.
.inad_effective_innovation_param(theta, tau, innovation)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.